@@ -2,7 +2,7 @@
 
 /*
 Copyright (C) 2005 Jean-Baptiste jb_dul@yahoo.com
-Copyright (C) 2005, 2006, 2007 Fabian Nowak timystery@arcor.de.
+Copyright (C) 2005-2008 Fabian Nowak timystery@arcor.de.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -54,7 +54,7 @@ on_activate_disk_display (GtkWidget *widget, t_disk * disk)
                         msg = _("The device \"%s\" should be removable safely "
                                     "now.");
                     else
-                        msg = _("An error occured. The device should not be "
+                        msg = _("An error occurred. The device should not be "
                                     "removed!");
 
                 my_dlg = gtk_message_dialog_new (NULL,
@@ -82,11 +82,40 @@ on_activate_disk_display (GtkWidget *widget, t_disk * disk)
 static void
 mounter_set_size (XfcePanelPlugin *plugin, int size, t_mounter *mt)
 {
-   /* schrink the gtk button's image to new size - */
+   /* shrink the gtk button's image to new size -*/
    gtk_widget_set_size_request (GTK_WIDGET(mt->button), size - 4, size - 4);
 
 }
 
+/**
+ * Format the long /dev/mapper/volume to something better:
+ *  LVM x:y
+ */
+void
+format_LVM_name (const char *disk_device, gchar **formatted_diskname)
+{
+
+    gint volume, logvol, i;
+
+    i = strlen(disk_device) - 1;
+
+    do
+        i--;
+    while (i>0 && g_ascii_isdigit(disk_device[i]) );
+    logvol = atoi(disk_device+i+1);
+
+    do
+        i--;
+    while (i>0 && g_ascii_isalpha (disk_device[i]));
+
+    do
+        i--;
+    while (i>0 && g_ascii_isdigit(disk_device[i]));
+    volume = atoi(disk_device+i+1);
+
+    *formatted_diskname = g_strdup_printf("LVM  %d:%d", volume, logvol);
+}
+
 
 /**
  * Create a new t_disk_display from t_disk infos.
@@ -94,7 +123,8 @@ mounter_set_size (XfcePanelPlugin *plugin, int size, t_mounter *mt)
 static t_disk_display*
 disk_display_new (t_disk *disk, t_mounter *mounter)
 {
-	t_disk_display * dd;
+    t_disk_display * dd;
+    char *formatted_diskname;
 
     TRACE ("enters disk_display_new");
 
@@ -110,10 +140,21 @@ disk_display_new (t_disk *disk, t_mounter *mounter)
         dd->hbox = gtk_hbox_new (FALSE, 10);
         gtk_container_add (GTK_CONTAINER(dd->menu_item), dd->hbox);
 
-        dd->label_disk = gtk_label_new (g_strconcat(disk->device, " -> ",
+        if (g_str_has_prefix(disk->device, "/dev/mapper/"))
+            format_LVM_name (disk->device, &formatted_diskname);
+        else
+            formatted_diskname = g_strdup(disk->device);
+
+        if (mounter->exclude_devicenames)
+        dd->label_disk = gtk_label_new (disk->mount_point);
+    else
+        dd->label_disk = gtk_label_new (g_strconcat(formatted_diskname, " -> ",
                                         disk->mount_point, NULL));
+
+    g_free (formatted_diskname);
+
         /*change to uniform label size*/
-        gtk_label_set_width_chars(GTK_LABEL(dd->label_disk),28);
+        gtk_label_set_width_chars(GTK_LABEL(dd->label_disk), 32);
         /* gtk_label_set_justify(GTK_LABEL(dd->label_disk),GTK_JUSTIFY_LEFT); */
         gtk_misc_set_alignment(GTK_MISC(dd->label_disk),0.0, 0.5);
         gtk_box_pack_start(GTK_BOX(dd->hbox),dd->label_disk,FALSE,TRUE,0);
@@ -140,10 +181,10 @@ disk_display_new (t_disk *disk, t_mounter *mounter)
 
 
 static void
-disk_display_refresh(t_disk_display * disk_display,
+disk_display_refresh (t_disk_display * disk_display,
                                  t_mount_info * mount_info)
 {
-	char * text;
+    char * text;
     char * used;
     char * size;
     char * avail;
@@ -155,13 +196,9 @@ disk_display_refresh(t_disk_display * disk_display,
         if (mount_info != NULL)
         {    /* device is mounted */
             used = get_size_human_readable (mount_info->used);
-            DBG("used is now : %s",used);
             size = get_size_human_readable (mount_info->size);
-            DBG("size is now : %s",size);
             avail = get_size_human_readable (mount_info->avail);
-            DBG("avail is now : %s",size);
             text = g_strdup_printf ("[%s/%s] %s free", used, size, avail);
-            DBG("text is now : %s",text);
 
             g_free(used);
             g_free(size);
@@ -223,29 +260,29 @@ mounter_data_new (t_mounter *mt)
     int i, res;
     t_disk * disk;
     t_disk_display * disk_display;
-    GPtrArray *array;
+    GPtrArray *array =  NULL;
     char *dev_mp; /* device or mountpoint */
     gboolean removed_device;
 
     /*get static infos from /etc/fstab */
     mt->pdisks = disks_new (mt->include_NFSs);
 
-	/* remove unwanted file systems from list */
-		if (mt->exclude_FSs) {
-		array = g_ptr_array_new();
-		DBG("excluded_filesystems=%s\n", mt->excluded_filesystems);
-		res = seperate_list(array, mt->excluded_filesystems);
-		for (i=0; i<array->len; i++) {
-			dev_mp = (char*) g_ptr_array_index(array, i);
-			if ( strstr(dev_mp , "/dev") )
-				removed_device = disks_remove_device(mt->pdisks, dev_mp);
-			else
-				removed_device = disks_remove_mountpoint (mt->pdisks, dev_mp);
-		}
-	}
+    /* remove unwanted file systems from list */
+    if (mt->exclude_FSs) {
+        array = g_ptr_array_new();
+        DBG("excluded_filesystems=%s\n", mt->excluded_filesystems);
+        res = seperate_list(array, mt->excluded_filesystems);
+        for (i=0; i<array->len; i++) {
+            dev_mp = (char*) g_ptr_array_index(array, i);
+            if ( strstr(dev_mp , "/dev") )
+                removed_device = disks_remove_device(mt->pdisks, dev_mp);
+            else
+                removed_device = disks_remove_mountpoint (mt->pdisks, dev_mp);
+        }
+    }
 
     /* get dynamic infos on mounts */
-    disks_refresh (mt->pdisks);
+    disks_refresh (mt->pdisks, array /* =GPtrArray *excluded_FSs */ );
 
     /* menu with menu_item */
     mt->menu = gtk_menu_new ();
@@ -278,6 +315,8 @@ mounter_data_new (t_mounter *mt)
 
     mt->eject_drives = FALSE;
 
+    mt->exclude_devicenames = FALSE;
+
     TRACE ("leaves mounter_data_new");
 
     return ;
@@ -298,6 +337,7 @@ mounter_refresh (t_mounter * mt)
     gboolean msg_dlg = mt->message_dialog;
     gboolean incl_NFSs = mt->include_NFSs;
     gboolean excl_FSs = mt->exclude_FSs;
+    gboolean excl_DNs = mt->exclude_devicenames;
     gboolean eject = mt->eject_drives;
 
     mounter_data_new (mt);
@@ -309,6 +349,7 @@ mounter_refresh (t_mounter * mt)
     mt->message_dialog = msg_dlg;
     mt->include_NFSs = incl_NFSs;
     mt->exclude_FSs = excl_FSs;
+    mt->exclude_devicenames = excl_DNs;
     mt->eject_drives = eject;
 
     TRACE ("leaves mounter_refresh");
@@ -355,8 +396,8 @@ mounter_read_config (XfcePanelPlugin *plugin, t_mounter *mt)
         mt->icon = g_strdup (value);
     else
         mt->icon = g_strdup_printf (
-				"%s/icons/hicolor/scalable/apps/xfce-mount.svg",
-				PACKAGE_DATA_DIR );
+                "%s/icons/hicolor/scalable/apps/xfce-mount.svg",
+                PACKAGE_DATA_DIR );
 
     if ( (value = xfce_rc_read_entry (rc, "mount_command", NULL)) )
         mt->mount_command = g_strdup (value);
@@ -382,6 +423,9 @@ mounter_read_config (XfcePanelPlugin *plugin, t_mounter *mt)
     if ( (value = xfce_rc_read_entry(rc, "exclude_FSs", NULL)) )
         mt->exclude_FSs= atoi (value);
 
+    if ( (value = xfce_rc_read_entry(rc, "exclude_devicenames", NULL)) )
+        mt->exclude_devicenames= atoi (value);
+
     if ( (value = xfce_rc_read_entry(rc, "eject_drives", NULL)) )
         mt->eject_drives= atoi (value);
 
@@ -431,6 +475,9 @@ mounter_write_config (XfcePanelPlugin *plugin, t_mounter *mt)
     if ( mt->exclude_FSs==1 )
         xfce_rc_write_entry (rc, "exclude_FSs", "1");
 
+    if ( mt->exclude_devicenames==1 )
+        xfce_rc_write_entry (rc, "exclude_devicenames", "1");
+
     if ( mt->eject_drives==1 )
         xfce_rc_write_entry (rc, "eject_drives", "1");
 
@@ -540,6 +587,9 @@ mounter_apply_options (t_mounter_dialog *md)
     mt->exclude_FSs = gtk_toggle_button_get_active
             (GTK_TOGGLE_BUTTON(md->show_exclude_FSs));
 
+    mt->exclude_devicenames = gtk_toggle_button_get_active
+            (GTK_TOGGLE_BUTTON(md->show_exclude_devicenames));
+
     if (mt->include_NFSs!=incl_NFSs || mt->exclude_FSs!=excl_FSs
         || strlen(mt->excluded_filesystems)!=0) {
             /* re-read disk information */
@@ -620,6 +670,14 @@ exlude_FSs_toggled (GtkWidget *widget, t_mounter_dialog *md)
 }
 
 
+static gboolean
+exclude_devicenames_toggled (GtkWidget *widget, t_mounter_dialog *md)
+{
+
+
+    return TRUE;
+}
+
 static void
 mounter_create_options (XfcePanelPlugin *plugin, t_mounter *mt)
 {
@@ -876,6 +934,25 @@ mounter_create_options (XfcePanelPlugin *plugin, t_mounter *mt)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(md->show_eject_drives),
                                 mt->eject_drives);
 
+    /* exclude device names */
+    _eventbox = gtk_event_box_new ();
+    gtk_box_pack_start (GTK_BOX (_vbox), GTK_WIDGET(_eventbox),
+                        FALSE, FALSE, 0);
+    gtk_widget_show (_eventbox);
+    gtk_tooltips_set_tip ( GTK_TOOLTIPS(tip), _eventbox,
+        _("Activate this option to only have the mount points be displayed."),
+        NULL );
+
+    md->show_exclude_devicenames = gtk_check_button_new_with_mnemonic (
+                                _("Display _mount points only") );
+
+    gtk_widget_show (md->show_exclude_devicenames);
+    gtk_container_add (GTK_CONTAINER (_eventbox), md->show_exclude_devicenames );
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(md->show_exclude_devicenames),
+                                mt->exclude_devicenames);
+
+
+
         /* Exclude file systems  */
     _eventbox = gtk_event_box_new ();
     gtk_box_pack_start (GTK_BOX (_vbox), GTK_WIDGET(_eventbox),
@@ -907,7 +984,7 @@ mounter_create_options (XfcePanelPlugin *plugin, t_mounter *mt)
     gtk_widget_show(md->string_excluded_filesystems);
     gtk_box_pack_start (GTK_BOX(_vbox2), md->string_excluded_filesystems, TRUE, TRUE, 0);
 
-    _label = gtk_label_new_with_mnemonic (_("_File sytems"));
+    _label = gtk_label_new_with_mnemonic (_("_File systems"));
     gtk_widget_show(_label);
     gtk_notebook_append_page (GTK_NOTEBOOK(_notebook), _vbox, _label);
 
