@@ -2,7 +2,7 @@
 
 /*
 Copyright (C) 2005 Jean-Baptiste jb_dul@yahoo.com
-Copyright (C) 2005, 2006, 2007 Fabian Nowak timystery@arcor.de.
+Copyright (C) 2005-2008 Fabian Nowak timystery@arcor.de.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -27,10 +27,12 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <config.h>
 #endif
 
-
-/* #define DEBUG 1
-#define DEBUG_TRACE 1 */
-
+#ifdef DEBUG
+#undef DEBUG
+#endif
+#ifdef DEBUG_TRACE
+#undef DEBUG_TRACE
+#endif
 
 #include <gtk/gtk.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
@@ -69,6 +71,7 @@ typedef struct
     gboolean message_dialog; /**< whether to show (un)success after umount */
     gboolean include_NFSs; /**< whether to also display network file systems */
     gboolean exclude_FSs;
+    gboolean exclude_devicenames;
     gboolean eject_drives;
     GtkWidget *button;
     GdkPixbuf *button_pb;
@@ -110,6 +113,7 @@ typedef struct
     GtkWidget *show_include_NFSs;
     GtkWidget *show_exclude_FSs;
     GtkWidget *show_eject_drives;
+    GtkWidget *show_exclude_devicenames;
     GtkWidget *string_excluded_filesystems;
 }
 t_mounter_dialog;
